==> batchcomputecli-0.0.20.tar.gz: batchcomputecli-0.0.20/src/batchcomputecli/actions/project/add_task.py <==
from ...services import project, printer, docker, client
import os
import json

def add(task_name, image_id=None, docker_image=None, oss_path=None):

    type = project.check_is_job_project()

    if type == 'java':
        raise Exception('java type project unsupported currently')

    with open('./job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    if obj['TaskDag']['TaskDescMap'].get(task_name) != None:
        raise Exception('Task %s already exists!' % task_name)



    obj['TaskDag']['TaskDescMap'][task_name] = getDefauleTaskDesc(task_name, type, image_id, docker_image, oss_path)

    with open('./job.json', 'w') as f:
        f.write(json.dumps(obj, indent=2))
    print('add task %s from job.json' % task_name)

    create_task_file(task_name, type)
    printer.done()

def create_task_file(name, type):

    cur_path = os.path.split(os.path.realpath(__file__))[0]

    temp_type = ''
    if type == 'python':
        temp_type = 'py'
    else:
        temp_type = 'sh'

    src = os.path.join(cur_path, '../../templates/add_task.%s' % temp_type)

    dist = os.path.join(os.getcwd(), 'src/%s.%s' % (name,temp_type))

    with open(src, 'r') as fr:
        v = fr.read()
    with open(dist, 'w') as f:
        f.write(v)
    print('add src/%s.%s success' % (name,temp_type))


def getDefauleTaskDesc(task_name, type, image_id, docker_image, oss_path):

    d = {
        "ImageId": __get_imgid(image_id, docker_image),
        "InstanceCount": 1,
        "OssMappingLocale": "UTF-8",
        "OssMappingLock": True,
        "OssMapping": {},
        "PackageUri": "",
        "EnvironmentVariables": {},
        "ResourceDescription": {
            "Cpu": 800,
            "Memory": 2000
        },
        "StderrRedirectPath": "",
        "StdoutRedirectPath": "",
        "Timeout": 3000
    }

    if type=='python':
        d["ProgramType"]="python"
        d["ProgramName"]="%s.py" % task_name
        d["ProgramArguments"]=""
    else:
        d["ProgramType"]='native'
        d["ProgramName"]="/bin/bash"
        d["ProgramArguments"]="%s.sh" % task_name

    if oss_path:
        d['PackageUri'] = '%sworker.tar.gz' % oss_path
        d['StdoutRedirectPath'] = '%slogs' % oss_path
        d['StderrRedirectPath'] = '%slogs' % oss_path

    if docker_image:
        info = docker.get_registry_oss_info()

        if ':' not in docker_image:
           docker_image =  "localhost:%s/%s" % (info.get('port'), docker_image)

        d['EnvironmentVariables'] = {
           "BATCH_COMPUTE_DOCKER_IMAGE": docker_image,  #localhost:32768/myubuntu
           "BATCH_COMPUTE_DOCKER_REGISTRY_OSS_PATH": "oss://%s/%s" % (info.get('OSS_BUCKET'), info.get('STORAGE_PATH')) #oss://mybucket/mydockerimages
        }

    return d

def __get_imgid(image_id, docker_image):

    if docker_image:
        arr = client.list_images()
        for n in arr:
            if n['Platform']=='Linux' and ('docker' in n['ImageName'].lower()):
                return n['ImageId']
    else:
        return image_id or ''

==> batchcomputecli-0.1.3.tar.gz: batchcomputecli-0.1.3/src/batchcomputecli/actions/project/add_task.py <==
from ...services import project, printer, docker, client
import os
import json

def add(task_name, image_id=None, docker_image=None, oss_path=None):

    type = project.check_is_job_project()

    if type == 'java':
        raise Exception('java type project unsupported currently')

    with open('./job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    if obj['TaskDag']['TaskDescMap'].get(task_name) != None:
        raise Exception('Task %s already exists!' % task_name)


    obj['TaskDag']['TaskDescMap'][task_name] = getDefauleTaskDesc(task_name, type, image_id, docker_image, oss_path)

    with open('./job.json', 'w') as f:
        f.write(json.dumps(obj, indent=2))

    print('add task %s to job.json' % task_name)

    create_task_file(task_name, type)
    printer.done()

def create_task_file(name, type):

    cur_path = os.path.split(os.path.realpath(__file__))[0]

    temp_type = ''
    if type == 'python':
        temp_type = 'py'
    else:
        temp_type = 'sh'

    src = os.path.join(cur_path, '../../templates/add_task.%s' % temp_type)

    dist = os.path.join(os.getcwd(), 'src/%s.%s' % (name,temp_type))

    with open(src, 'r') as fr:
        v = fr.read()
    with open(dist, 'w') as f:
        f.write(v)
    print('add src/%s.%s success' % (name,temp_type))


def getDefauleTaskDesc(task_name, type, image_id, docker_image, oss_path):

    d = {
        "ImageId": __get_imgid(image_id, docker_image),
        "InstanceCount": 1,
        "OssMappingLocale": "UTF-8",
        "OssMappingLock": True,
        "OssMapping": {},
        "PackageUri": "",
        "EnvironmentVariables": {},
        "ResourceDescription": {
            "Cpu": 800,
            "Memory": 2000
        },
        "StderrRedirectPath": "",
        "StdoutRedirectPath": "",
        "Timeout": 3000
    }

    if type=='python':
        d["ProgramType"]="python"
        d["ProgramName"]="%s.py" % task_name
        d["ProgramArguments"]=""
    else:
        d["ProgramType"]='native'
        d["ProgramName"]="/bin/bash"
        d["ProgramArguments"]="%s.sh" % task_name

    if oss_path:
        d['PackageUri'] = '%sworker.tar.gz' % oss_path
        d['StdoutRedirectPath'] = '%slogs' % oss_path
        d['StderrRedirectPath'] = '%slogs' % oss_path

    if docker_image:
        info = docker.get_registry_oss_info()

        if ':' not in docker_image:
           docker_image = "localhost:%s/%s" % (info.get('port'), docker_image)

        d['EnvironmentVariables'] = {
           "BATCH_COMPUTE_DOCKER_IMAGE": docker_image,  #localhost:32768/myubuntu
           "BATCH_COMPUTE_DOCKER_REGISTRY_OSS_PATH": "oss://%s/%s" % (info.get('OSS_BUCKET'), info.get('STORAGE_PATH')) #oss://mybucket/mydockerimages
        }

    return d

def __get_imgid(image_id, docker_image):

    if docker_image:
        arr = client.list_images()
        for n in arr:
            if n['Platform']=='Linux' and ('docker' in n['ImageName'].lower()):
                return n['ImageId']
    else:
        return image_id or ''
